@@ -1,21 +1,6 @@
-/***************************************************************************
-                          kmagselrect.h  -  description
-                             -------------------
-    begin                : Mon Feb 12 23:45:41 EST 2001
-    copyright            : (C) 2001-2003 by Sarang Lakare
-    email                : sarang#users.sf.net
-    copyright            : (C) 2003-2004 by Olaf Schmidt
-    email                : ojschmidt@kde.org
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2001-2003 Sarang Lakare <sarang@users.sourceforge.net>
+// SPDX-FileCopyrightText: 2003-2004 Olaf Schmidt <ojschmidt@kde.org>
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef KMAGSELRECT_H
 #define KMAGSELRECT_H
